Resolves a WRDS username from, in order, an explicit argument, WRDS_ID,
WRDS_USER, and the keyring entry written by wrds::wrds_set_credentials().
Usage
wrds_get_username(
wrds_id = NULL,
user_key = "wrds_user",
prompt = interactive()
)Resolves a WRDS username from, in order, an explicit argument, WRDS_ID,
WRDS_USER, and the keyring entry written by wrds::wrds_set_credentials().
wrds_get_username(
wrds_id = NULL,
user_key = "wrds_user",
prompt = interactive()
)